@@ -3,11 +3,11 @@ import xarray
 import matplotlib.pyplot as plt
 
 class objearth():
-    def __init__(self,DataArray,lst=True):
+    def __init__(self,DataArray):
         self.DataArray = DataArray
-        self.lst=lst
 
-    def plotshow(self):
+    def plotshow(self,lst=True):
+        self.lst = lst
         if type(self.DataArray) == xarray.core.dataarray.DataArray:
             if self.lst==True:
                 ymax = 0 ; ymin = self.DataArray.shape[0]
